# `cwlbrowser`
## `cwlbrowser` is a python library that allows you to open, browse and compare scientific workflows written in CWL on a Jupyter notebook

### Installation
`pip install cwlbrowser`

### Documentation
Detailed documentation of usage can be found [here:](https://gitlab.cs.man.ac.uk/mbaxasp7/cwlbrowser/blob/master/doc/documentation.md)


